@@ -69,16 +69,18 @@ class Step(Config):
 
         return v
 
-    def make(self, optimizer):
-        return lr_scheduler.step_scheduler(
-            optimizer,
-            self.lr,
-            self.milestones,
-            self.gamma,
-            self.warmup,
-            self.warmup_multiplier,
+    def make(self, optimizer, **kwargs):
+        argument = override(
+            kwargs,
+            lr=self.lr,
+            milestones=self.milestones,
+            gamma=self.gamma,
+            warmup=self.warmup,
+            warmup_multiplier=self.warmup_multiplier,
         )
 
+        return lr_scheduler.step_scheduler(optimizer, **argument)
+
 
 class Exp(TypedConfig):
     __type__ = "exp"
@@ -144,9 +146,15 @@ class LRFind(Config):
 
         return v
 
-    def make(self, optimizer):
+    def make(self, optimizer, **kwargs):
+        argument = override(kwargs,
+                            lr_min=self.lr_min
+                            lr_max=self.lr_max,
+                            n_iter=self.n_iter
+                            linear=self.linear)
+        
         return lr_scheduler.lr_finder(
-            optimizer, self.lr_min, self.lr_max, self.n_iter, self.linear
+            optimizer, **argument
         )
 
 
