@@ -23,16 +23,18 @@ class SGD(Config):
 
         return v
 
-    def make(self, params):
-        return optim.SGD(
-            params,
-            self.lr,
-            self.momentum,
-            self.dampening,
-            self.weight_decay,
-            self.nesterov,
+    def make(self, params, **kwargs):
+        argument = override(
+            kwargs,
+            lr=self.lr,
+            momentum=self.momentum,
+            dampening=self.dampening,
+            weight_decay=self.weight_decay,
+            nesterov=self.nesterov,
         )
 
+        return optim.SGD(params, **argument)
+
 
 class Adam(Config):
     type: StrictStr
@@ -50,11 +52,18 @@ class Adam(Config):
 
         return v
 
-    def make(self, params):
-        return optim.Adam(
-            params, self.lr, self.betas, self.eps, self.weight_decay, self.amsgrad
+    def make(self, params, **kwargs):
+        argument = override(
+            kwargs,
+            lr=self.lr,
+            betas=self.betas,
+            eps=self.eps,
+            weight_decay=self.weight_decay,
+            amsgrad=self.amsgrad,
         )
 
+        return optim.Adam(params, **argument)
+
 
 class AdamW(Config):
     type: StrictStr
@@ -72,11 +81,18 @@ class AdamW(Config):
 
         return v
 
-    def make(self, params):
-        return optim.AdamW(
-            params, self.lr, self.betas, self.eps, self.weight_decay, self.amsgrad
+    def make(self, params, **kwargs):
+        argument = override(
+            kwargs,
+            lr=self.lr,
+            betas=self.betas,
+            eps=self.eps,
+            weight_decay=self.weight_decay,
+            amsgrad=self.amsgrad,
         )
 
+        return optim.AdamW(params, **argument)
+
 
 class LAMB(Config):
     type: StrictStr
@@ -93,11 +109,17 @@ class LAMB(Config):
 
         return v
 
-    def make(self, params):
-        return tensor_optim.LAMB(
-            params, self.lr, self.betas, self.eps, self.weight_decay
+    def make(self, params, **kwargs):
+        argument = override(
+            kwargs,
+            lr=self.lr,
+            betas=self.betas,
+            eps=self.eps,
+            weight_decay=self.weight_decay,
         )
 
+        return tensor_optim.LAMB(params, **argument)
+
 
 class RMSpropTF(TypedConfig):
     __type__ = "rmsprop_tf"
