@@ -4,7 +4,7 @@ from torch.utils import cpp_extension as cpp_ext
 class LazyExtension:
     def __init__(self, name, sources):
         self.name = name
-        self.sources
+        self.sources = sources
         self.loaded = False
         self.extension = None
 
